##  Activating the ESG Capability Optional Feature
As an admin, you can activate the ESG capability optional feature in the Optional Features & Early Access section of the administration area. Upon activation, the following changes take place:
  * The ESG capability is added to the meta model. If the workspace is configured for the meta model v4, the ESG capability is added as a subtype of the business context fact sheet. If the workspace is configured for the meta model v3, the ESG capability is introduced as a new fact sheet type.
  * A set of 44 ESG capability fact sheets, based on our recommendations, are created. The user who activated the feature is designated as the creator of these fact sheets and their associated relations.
